aboutsummaryrefslogtreecommitdiffstats
path: root/arch/s390/kernel/setup.c
diff options
context:
space:
mode:
authorHeiko Carstens <hca@linux.ibm.com>2021-07-21 10:56:57 +0200
committerHeiko Carstens <hca@linux.ibm.com>2021-07-27 09:39:20 +0200
commit511ad531afd4090625def4d9aba1f5227bd44b8e (patch)
treeac43a26d80aa6d2957f6b8c4f028d12391c86b5e /arch/s390/kernel/setup.c
parents390: add HWCAP_S390_PCI_MIO to ELF hwcaps (diff)
downloadlinux-dev-511ad531afd4090625def4d9aba1f5227bd44b8e.tar.xz
linux-dev-511ad531afd4090625def4d9aba1f5227bd44b8e.zip
s390/hwcaps: shorten HWCAP defines
Remove s390 part of all HWCAP defines, just to make them shorter and easier to handle. The namespace is anyway per architecture. This is similar to what arm64 has. Signed-off-by: Heiko Carstens <hca@linux.ibm.com>
Diffstat (limited to 'arch/s390/kernel/setup.c')
-rw-r--r--arch/s390/kernel/setup.c52
1 files changed, 26 insertions, 26 deletions
diff --git a/arch/s390/kernel/setup.c b/arch/s390/kernel/setup.c
index 1c0ab3030801..9d480456cd26 100644
--- a/arch/s390/kernel/setup.c
+++ b/arch/s390/kernel/setup.c
@@ -888,17 +888,17 @@ static int __init setup_hwcaps(void)
* Bit 22: extended-translation facility 3 is installed
* Bit 30: extended-translation facility 3 enhancement facility
* These get translated to:
* HWCAP_S390_ESAN3 bit 0, HWCAP_S390_ZARCH bit 1,
* HWCAP_S390_STFLE bit 2, HWCAP_S390_MSA bit 3,
* HWCAP_S390_LDISP bit 4, HWCAP_S390_EIMM bit 5 and
* HWCAP_S390_ETF3EH bit 8 (22 && 30).
*/
for (i = 0; i < 6; i++)
if (test_facility(stfl_bits[i]))
elf_hwcap |= 1UL << i;
if (test_facility(22) && test_facility(30))
- elf_hwcap |= HWCAP_S390_ETF3EH;
+ elf_hwcap |= HWCAP_ETF3EH;
/*
* Check for additional facilities with store-facility-list-extended.
@@ -911,61 +911,61 @@ static int __init setup_hwcaps(void)
* Bit 42: decimal floating point facility is installed
* Bit 44: perform floating point operation facility is installed
* translated to:
- * HWCAP_S390_DFP bit 6 (42 && 44).
+ * HWCAP_DFP bit 6 (42 && 44).
*/
if ((elf_hwcap & (1UL << 2)) && test_facility(42) && test_facility(44))
- elf_hwcap |= HWCAP_S390_DFP;
+ elf_hwcap |= HWCAP_DFP;
/*
* Huge page support HWCAP_S390_HPAGE is bit 7.
*/
if (MACHINE_HAS_EDAT1)
- elf_hwcap |= HWCAP_S390_HPAGE;
+ elf_hwcap |= HWCAP_HPAGE;
/*
* 64-bit register support for 31-bit processes
- * HWCAP_S390_HIGH_GPRS is bit 9.
+ * HWCAP_HIGH_GPRS is bit 9.
*/
- elf_hwcap |= HWCAP_S390_HIGH_GPRS;
+ elf_hwcap |= HWCAP_HIGH_GPRS;
/*
* Transactional execution support HWCAP_S390_TE is bit 10.
*/
if (MACHINE_HAS_TE)
- elf_hwcap |= HWCAP_S390_TE;
+ elf_hwcap |= HWCAP_TE;
/*
* Vector extension HWCAP_S390_VXRS is bit 11. The Vector extension
* can be disabled with the "novx" parameter. Use MACHINE_HAS_VX
* instead of facility bit 129.
*/
if (MACHINE_HAS_VX) {
- elf_hwcap |= HWCAP_S390_VXRS;
+ elf_hwcap |= HWCAP_VXRS;
if (test_facility(134))
- elf_hwcap |= HWCAP_S390_VXRS_BCD;
+ elf_hwcap |= HWCAP_VXRS_BCD;
if (test_facility(135))
- elf_hwcap |= HWCAP_S390_VXRS_EXT;
+ elf_hwcap |= HWCAP_VXRS_EXT;
if (test_facility(148))
- elf_hwcap |= HWCAP_S390_VXRS_EXT2;
+ elf_hwcap |= HWCAP_VXRS_EXT2;
if (test_facility(152))
- elf_hwcap |= HWCAP_S390_VXRS_PDE;
+ elf_hwcap |= HWCAP_VXRS_PDE;
if (test_facility(192))
- elf_hwcap |= HWCAP_S390_VXRS_PDE2;
+ elf_hwcap |= HWCAP_VXRS_PDE2;
}
if (test_facility(150))
- elf_hwcap |= HWCAP_S390_SORT;
+ elf_hwcap |= HWCAP_SORT;
if (test_facility(151))
- elf_hwcap |= HWCAP_S390_DFLT;
+ elf_hwcap |= HWCAP_DFLT;
if (test_facility(165))
- elf_hwcap |= HWCAP_S390_NNPA;
+ elf_hwcap |= HWCAP_NNPA;
/*
* Guarded storage support HWCAP_S390_GS is bit 12.
*/
if (MACHINE_HAS_GS)
- elf_hwcap |= HWCAP_S390_GS;
+ elf_hwcap |= HWCAP_GS;
if (MACHINE_HAS_PCI_MIO)
- elf_hwcap |= HWCAP_S390_PCI_MIO;
+ elf_hwcap |= HWCAP_PCI_MIO;
get_cpu_id(&cpu_id);
add_device_randomness(&cpu_id, sizeof(cpu_id));
@@ -888,17 +888,17 @@ static int __init setup_hwcaps(void)
* Bit 30: extended-translation facility 3 enhancement facility
* These get translated to:
- * HWCAP_S390_ESAN3 bit 0, HWCAP_S390_ZARCH bit 1,
- * HWCAP_S390_STFLE bit 2, HWCAP_S390_MSA bit 3,
- * HWCAP_S390_LDISP bit 4, HWCAP_S390_EIMM bit 5 and
- * HWCAP_S390_ETF3EH bit 8 (22 && 30).
+ * HWCAP_ESAN3 bit 0, HWCAP_ZARCH bit 1,
+ * HWCAP_STFLE bit 2, HWCAP_MSA bit 3,
+ * HWCAP_LDISP bit 4, HWCAP_EIMM bit 5 and
+ * HWCAP_ETF3EH bit 8 (22 && 30).
*/
for (i = 0; i < 6; i++)
@@ -911,61 +911,61 @@ static int __init setup_hwcaps(void)
/*
- * Huge page support HWCAP_S390_HPAGE is bit 7.
+ * Huge page support HWCAP_HPAGE is bit 7.
*/
if (MACHINE_HAS_EDAT1)
@@ -911,61 +911,61 @@ static int __init setup_hwcaps(void)
/*
- * Transactional execution support HWCAP_S390_TE is bit 10.
+ * Transactional execution support HWCAP_TE is bit 10.
*/
if (MACHINE_HAS_TE)
@@ -911,61 +911,61 @@ static int __init setup_hwcaps(void)
/*
- * Vector extension HWCAP_S390_VXRS is bit 11. The Vector extension
+ * Vector extension HWCAP_VXRS is bit 11. The Vector extension
* can be disabled with the "novx" parameter. Use MACHINE_HAS_VX
* instead of facility bit 129.
@@ -911,61 +911,61 @@ static int __init setup_hwcaps(void)
/*
- * Guarded storage support HWCAP_S390_GS is bit 12.
+ * Guarded storage support HWCAP_GS is bit 12.
*/
if (MACHINE_HAS_GS)